import { BrowserRouter, Routes, Route } from 'react-router-dom';

import {
  AdicionarDado,
  AdicionarMaterial,
  CadastroResponsavel,
  ForumList,
  Login,
  ReportHistory,
  ReportViewEdit,
} from './screens';
import AdicionarAnotacao from './screens/AdicionarAnotacao';
import AdicionarPostagem from './screens/AdicionarPostagem';
import AdicionarRelatorio from './screens/AdicionarRelatorio';
import AnnotationList from './screens/AnnotationList';
import AreaAluno from './screens/AreaAluno';
import CadastroAluno from './screens/CadastroAluno';
import CadastroEspecialista from './screens/CadastroEspecialista';
import CadastroProfessor from './screens/CadastroProfessor';
import ListaMaterialScreen from './screens/ListMaterialModularScreensV2';
import MenuCoordenador from './screens/MenuCoordenador';
import MenuEspecialista from './screens/MenuEspecialista';
import MenuProfessor from './screens/MenuProfessor';
import SeeAnnotation from './screens/SeeAnnotation';
import StudentList from './screens/StudentList';
import UserList from './screens/UserList';
import VisualizacaoMateriais from './screens/VisualizacaoMateriais';

function App() {
  return (
    <div>
      <BrowserRouter>
        <Routes>
          <Route path="/" element={<Login />} />

          <Route path="/area-coordenador" element={<MenuCoordenador />} />
          <Route path="/area-professor" element={<MenuProfessor />} />
          <Route path="/area-especialista" element={<MenuEspecialista />} />
          <Route path="/adicionar-material" element={<AdicionarMaterial />} />
          <Route
            path="/area-especialista/editar-material/:id"
            element={<AdicionarMaterial />}
          />
          <Route path="/lista-usuarios" element={<UserList />} />
          <Route path="/lista-alunos-professor" element={<StudentList />} />
          <Route
            path="/lista-alunos-coordenador"
            element={<StudentList isCoordinator />}
          />
          <Route path="/adicionar-postagem" element={<AdicionarPostagem />} />
          <Route path="/cadastrar-aluno" element={<CadastroAluno />} />
          <Route path="/editar-aluno/:id" element={<CadastroAluno />} />
          <Route path="/cadastro-professor" element={<CadastroProfessor />} />
          <Route path="/editar-professor/:id" element={<CadastroProfessor />} />
          <Route path="/area-aluno/:id" element={<AreaAluno />} />
          <Route
            path="/area-aluno/:idAluno/cadastrar-dado"
            element={<AdicionarDado />}
          />
          <Route
            path="/area-aluno/:idAluno/lista-anotacoes"
            element={<AnnotationList />}
          />
          <Route
            path="/area-aluno/:idAluno/lista-anotacoes/:id"
            element={<SeeAnnotation />}
          />
          <Route
            path="/area-aluno/:idAluno/adicionar-anotacao"
            element={<AdicionarAnotacao />}
          />
          <Route
            path="/area-aluno/:idAluno/editar-dado/:id"
            element={<AdicionarDado />}
          />
          <Route
            path="/area-aluno/:idAluno/visualizar-dado/:id"
            element={<AdicionarDado justView />}
          />
          <Route
            path="/cadastro-especialista"
            element={<CadastroEspecialista />}
          />
          <Route
            path="/editar-especialista/:id"
            element={<CadastroEspecialista />}
          />
          <Route
            path="/cadastro-responsavel"
            element={<CadastroResponsavel />}
          />
          <Route
            path="/editar-responsavel/:id"
            element={<CadastroResponsavel />}
          />
          <Route
            path="/area-professor/lista-materiais"
            element={<ListaMaterialScreen user="professor" />}
          />
          <Route
            path="/area-especialista/lista-materiais"
            element={<ListaMaterialScreen user="especialista" />}
          />
          <Route
            path="/area-especialista/meus-materiais"
            element={<ListaMaterialScreen user="especialista" isMyMaterials />}
          />
          <Route
            path="/area-professor/visualizacao-materiais/:id"
            element={<VisualizacaoMateriais user="professor" />}
          />
          <Route
            path="/area-especialista/visualizacao-materiais/:id"
            element={<VisualizacaoMateriais user="especialista" />}
          />
          <Route path="/area-aluno" element={<AreaAluno />} />
          <Route
            path="/area-aluno/:idAluno/adicionar-relatorio"
            element={<AdicionarRelatorio />}
          />
          <Route
            path="/area-aluno/:idAluno/historico-relatorios"
            element={<ReportHistory />}
          />
          <Route
            path="/area-aluno/:idAluno/visualizar-relatorios/:id"
            element={<ReportViewEdit justView />}
          />
          <Route
            path="/area-aluno/:idAluno/editar-relatorios/:id"
            element={<ReportViewEdit />}
          />
          <Route path="/forum-lista-posts" element={<ForumList />} />
        </Routes>
      </BrowserRouter>
    </div>
  );
}

export default App;
