import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import Select, {
  components,
  DropdownIndicatorProps,
  GroupBase,
} from 'react-select';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
/* eslint-disable react/jsx-props-no-spreading */

const defaultProps = {
  isMulti: true,
  selectText: 'Selecione...',
  options: [
    { value: 'chocolate', label: 'Chocolate' },
    { value: 'strawberry', label: 'Strawberry' },
    { value: 'vanilla', label: 'Vanilla' },
  ],
  val: Array<any>(),
  widthContainer: '20rem',
};

type DropDownProps = {
  isMulti?: boolean;
  selectText?: string;
  options?: object;
  // eslint-disable-next-line react/require-default-props
  onChange?: (value: any) => void;
  val?: Array<any>;
  widthContainer?: string;
} & typeof defaultProps;

const styles = {
  fa: {
    fontSize: '28px',
    color: '#4F4F4F',
  },
};

const customStyles = {
  option: (provided: any, state: { isSelected: any }) => ({
    ...provided,
    color: '#4F4F4F',
    fontStyle: 'Roboto',
    padding: 2,
    fontSize: 14,
  }),
  multiValueLabel: () => ({
    color: 'white',
    fontSize: 15,
    fontWeight: 400,
    backgroundColor: colors.theme.blue,
    padding: 3,
    paddingRight: 0,
    paddingLeft: 7,
    borderTopLeftRadius: 5,
    borderBottomLeftRadius: 5,
  }),
  container: () => ({
    padding: 2,
    border: '1px solid #4F4F4F',
    borderRadius: 5,
    backgroundColor: 'white',
  }),
  control: () => ({
    width: '100%',
    border: '1px solid #white',
    display: 'flex',
  }),
  indicatorsContainer: () => ({
    width: '17%',
    display: 'flex',
  }),
  indicatorSeparator: () => ({
    display: 'none',
  }),
  menuList: () => ({
    color: 'white',
    padding: 5,
    border: '1px solid #4F4F4F',
    paddingRight: 0,
    paddingLeft: 10,
    borderBottomLeftRadius: 5,
    borderBottomRightRadius: 5,
  }),
  multiValueRemove: () => ({
    color: 'white',
    backgroundColor: colors.theme.blue,
    padding: 3,
    borderTopRightRadius: 6,
    borderBottomRightRadius: 6,
  }),
  singleValue: (provided: any, state: { isDisabled: any }) => {
    const opacity = state.isDisabled ? 0.5 : 1;
    const transition = 'opacity 300ms';

    return { ...provided, opacity, transition };
  },
};

function DropdownIndicator(
  props: JSX.IntrinsicAttributes &
    DropdownIndicatorProps<unknown, boolean, GroupBase<unknown>>,
) {
  return (
    <components.DropdownIndicator {...props}>
      <FontAwesomeIcon
        icon={fontawesome.icons.faCircleChevronDown}
        style={styles.fa}
      />
    </components.DropdownIndicator>
  );
}

function DropDown(props: DropDownProps) {
  const { isMulti, selectText, options, onChange, val, widthContainer } = props;

  const renderSelect = () => {
    if (onChange) {
      return (
        <Select
          placeholder={selectText}
          components={{ DropdownIndicator, ClearIndicator: () => null }}
          styles={customStyles}
          isMulti={isMulti}
          options={options}
          onChange={onChange}
          value={options.filter(item => val.includes(item.value))}
        />
      );
    }
    return (
      <Select
        placeholder={selectText}
        components={{ DropdownIndicator, ClearIndicator: () => null }}
        styles={customStyles}
        isMulti={isMulti}
        options={options}
      />
    );
  };

  return (
    <div className="dropdown" style={{ width: widthContainer }}>
      {renderSelect()}
    </div>
  );
}

DropDown.defaultProps = defaultProps;

export default DropDown;
