import React from 'react';

import colors from '../utils/colors';

const defaultProps = {
  text: 'Título',
  subtitle: '',
  fontWeight: '900',
  fontStyle: 'roboto',
  color: colors.theme.black,
  textSize: '1em',
  textAlign: 'center',
  colorSubtitle: colors.theme.placeholder,
};

type TitleProps = {
  text?: string;
  subtitle?: string;
  fontWeight?: string;
  fontStyle?: string;
  color?: string;
  textSize?: string;
  textAlign?: any;
  colorSubtitle?: string;
} & typeof defaultProps;

function TitleComponent(props: TitleProps) {
  const {
    text,
    fontStyle,
    subtitle,
    fontWeight,
    color,
    textSize,
    textAlign,
    colorSubtitle,
  } = props;

  const styles = {
    title: {
      fontSize: textSize,
      textAlign,
      fontWeight,
      color,
      margin: '0',
    },
    subtitle: {
      fontWeight: '400',
      textSize: '1em',
      textAlign,
      color: colorSubtitle,
    },
  };
  return (
    <div>
      <p style={styles.title}>{text}</p>
      {subtitle.length > 0 ? <p style={styles.subtitle}>{subtitle}</p> : null}
    </div>
  );
}

TitleComponent.defaultProps = defaultProps;

export default TitleComponent;
