import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  title: 'Social',
  description:
    'A expressão Lorem ipsumaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa...',
  onClickTitle: () => {
    console.log('title');
  },
  onClickEdit: () => {
    console.log('edit');
  },
  disableEdit: true,
};

type CardAlunoProps = {
  title?: string;
  description?: string;
  onClickTitle?: () => void;
  onClickEdit?: () => void;
  disableEdit?: boolean;
} & typeof defaultProps;

function CardAluno(props: CardAlunoProps) {
  const { title, description, onClickTitle, onClickEdit, disableEdit } = props;

  const styles = {
    container: {
      width: '18rem',
      height: '8.25em',
      background: '#FFFFFF',
      boxShadow: '0.094rem 0.156rem 0.256rem rgba(0, 0, 0, 0.25)',
      borderRadius: '0.313rem',
      overflow: 'hidden',
    },
    firstRow: {
      display: 'flex',
      flexDirection: 'row' as const,
    },
    pen: {
      backgroundColor: 'none',
      right: '0.1rem',
      top: 0,
      position: 'absolute' as const,
      outline: 'none',
      boxShadow: 'none',
    },
    description: {},
    buttonTitle: {
      outline: 'none',
      boxShadow: 'none',
      margin: 0,
      padding: 0,
    },
    titleStyle: {
      fontStyle: 'poppins',
    },
    line: {
      margin: 0,
      padding: 0,
    },
  };

  return (
    <div className="card" style={styles.container}>
      <div className="card-body">
        <div style={styles.firstRow}>
          <button
            type="button"
            className="btn btn-primary-*"
            style={styles.buttonTitle}
            onClick={onClickTitle}
          >
            <h5 className="card-title" style={styles.titleStyle}>
              {title}
            </h5>
          </button>
          {disableEdit && (
            <button
              type="button"
              className="btn btn-outline-*"
              style={styles.pen}
              onClick={onClickEdit}
            >
              <FontAwesomeIcon icon={fontawesome.icons.faPen} />
            </button>
          )}
        </div>
        <hr style={styles.line} />
        <p className="card-text" style={styles.description}>
          {description}
        </p>
        <button type="button" className="btn btn-outline-*" style={styles.pen}>
          <FontAwesomeIcon icon={fontawesome.icons.faPen} />
        </button>
      </div>
    </div>
  );
}

CardAluno.defaultProps = defaultProps;

export default CardAluno;
