import { useEffect, useState } from 'react';
import InputMask from 'react-input-mask';
import { useNavigate } from 'react-router-dom';

import { ButtonCard, DropDown } from '../components';

import TextArea from '../components/TextArea';
import TextField from '../components/TextField';
import { Responsible } from '../model/responsible';
import { Student } from '../model/student';
import { Teacher } from '../model/teacher';
import { User } from '../model/user';
import { getAllResponsibles } from '../services/responsible';
import { CreateStudentPayload, deleteStudent } from '../services/student';
import { getAllTeachers } from '../services/teacher';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import Modal from './Modal';

const defaultProps = {
  className: 'formComponent',
  studentData: {},
  isEdicao: false,
};

type formComponentStudentProps = {
  className?: string;
  studentData?: Student;
  onClickSubmit: (student: CreateStudentPayload) => void;
  isEdicao?: boolean;
  handleClickDelete: () => void;
} & typeof defaultProps;

function FormComponentStudent(props: formComponentStudentProps) {
  const navigate = useNavigate();
  const { className, studentData, onClickSubmit, isEdicao, handleClickDelete } =
    props;

  const styles = {
    container: {
      flex: 1,
      background: colors.theme.background,
      minHeight: '100vh',
      textAlign: 'center' as const,
    },
    modal: {
      position: 'absolute' as const,
      alignself: 'center',
      justifyContent: 'center',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
    },
    buttons: {
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
    button: {
      margin: 10,
    },
    wrapper: {
      alignItems: 'center',
      textAlign: 'center' as const,
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
  };

  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalDelete, setModalDelete] = useState(false);
  const [modalDeleteConfirmed, setModalDeleteConfirmed] = useState(false);

  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalDelete = () => {
    setModalDelete(!modalDelete);
  };
  const toggleModalDeleteConfirmed = () => {
    setModalDeleteConfirmed(!modalDeleteConfirmed);
  };

  const [name, setName] = useState('');
  const [birth, setBirth] = useState('');
  const [condition, setCondition] = useState('');
  const [grade, setGrade] = useState('');
  const [serie, setSerie] = useState('');
  const [observations, setObservations] = useState('');
  const [teacher, setTeacher] = useState<Teacher[]>([]);
  const [responsible, setResponsible] = useState<Responsible[]>([]);
  const [selectedTeachers, setSelectedTeachers] = useState<number[]>([]);
  const [selectedResponsibles, setSelectedResponsibles] = useState<number[]>(
    [],
  );
  const [nameRed, setNameRed] = useState(false);
  const [birthRed, setBirthRed] = useState('#4F4F4F');
  const [conditionRed, setConditionRed] = useState(false);
  const [gradeRed, setGradeRed] = useState(false);
  const [serieRed, setSerieRed] = useState(false);
  const [selectedTeachersRed, setSelectedTeachersRed] = useState(false);
  const [selectedResponsiblesRed, setSeselectedResponsiblesRed] =
    useState(false);
  const validBirth =
    /^(0[1-9]|[12][0-9]|3[01])[- /.](0[1-9]|1[012])[- /.](19|20)\d\d$/;
  const createPayload = (): CreateStudentPayload => {
    const payloadStudent: CreateStudentPayload = {
      name,
      birth_date: birth,
      condition,
      condition_level: grade,
      serie,
      teachers: selectedTeachers,
      responsibles: selectedResponsibles,
    };
    if (observations.length !== 0) {
      payloadStudent.observations = observations;
    }
    return payloadStudent;
  };

  useEffect(() => {
    setName(studentData.name);
    setBirth(studentData.birth_date);
    setCondition(studentData.condition);
    setGrade(studentData.condition_level);
    setSerie(studentData.serie);
    setObservations(studentData.observations ? studentData.observations : '');
    setSelectedTeachers(studentData.teachers);
    setSelectedResponsibles(studentData.responsibles);
    const getTeacher = async () => {
      try {
        const getTeacherResponse: Teacher[] = await getAllTeachers();
        setTeacher(getTeacherResponse);
      } catch (err) {
        console.log(err);
      }
    };
    const getResponsible = async () => {
      try {
        const getResponsibleResponse: Responsible[] =
          await getAllResponsibles();
        setResponsible(getResponsibleResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getTeacher();
    getResponsible();
  }, [studentData]);

  const teachers: any = [];
  for (let i = 0; i < teacher.length; i++) {
    teachers.push({ value: teacher[i].id, label: teacher[i].name });
  }
  const responsibles: any = [];
  for (let i = 0; i < responsible.length; i++) {
    responsibles.push({ value: responsible[i].id, label: responsible[i].name });
  }

  const onConfirm = () => {
    if (
      name === undefined ||
      birth === undefined ||
      !validBirth.test(birth) ||
      condition === undefined ||
      grade === undefined ||
      serie === undefined ||
      selectedTeachers === undefined ||
      selectedResponsibles === undefined
    ) {
      if (name === undefined) {
        setNameRed(true);
      } else if (name.length === 0) {
        setNameRed(true);
      } else {
        setNameRed(false);
      }
      if (birth === undefined) {
        setBirthRed(colors.theme.cancel);
      } else if (birth.length === 0) {
        setBirthRed(colors.theme.cancel);
      } else if (!validBirth.test(birth)) {
        setBirthRed(colors.theme.cancel);
      } else {
        setBirthRed('#4F4F4F');
      }
      if (condition === undefined) {
        setConditionRed(true);
      } else if (condition.length === 0) {
        setConditionRed(true);
      } else {
        setConditionRed(false);
      }
      if (grade === undefined) {
        setGradeRed(true);
      } else if (grade.length === 0) {
        setGradeRed(true);
      } else {
        setGradeRed(false);
      }
      if (serie === undefined) {
        setSerieRed(true);
      } else if (serie.length === 0) {
        setSerieRed(true);
      } else {
        setSerieRed(false);
      }
      if (selectedTeachers === undefined) {
        setSelectedTeachersRed(true);
      } else if (selectedTeachers.length === 0) {
        setSelectedTeachersRed(true);
      } else {
        setSelectedTeachersRed(false);
      }
      if (selectedResponsibles === undefined) {
        setSeselectedResponsiblesRed(true);
      } else if (selectedResponsibles.length === 0) {
        setSeselectedResponsiblesRed(true);
      } else {
        setSeselectedResponsiblesRed(false);
      }

      toggleModalEmpty();
    } else if (
      name.length === 0 ||
      birth.length === 0 ||
      condition.length === 0 ||
      grade.length === 0 ||
      serie.length === 0 ||
      selectedTeachers.length === 0 ||
      selectedResponsibles.length === 0
    ) {
      if (name.length === 0) {
        setNameRed(true);
      } else {
        setNameRed(false);
      }
      if (birth.length === 0) {
        setBirthRed(colors.theme.cancel);
      } else if (!validBirth.test(birth)) {
        setBirthRed(colors.theme.cancel);
      } else {
        setBirthRed('#4F4F4F');
      }
      if (condition.length === 0) {
        setConditionRed(true);
      } else {
        setConditionRed(false);
      }
      if (grade.length === 0) {
        setGradeRed(true);
      } else {
        setGradeRed(false);
      }
      if (serie.length === 0) {
        setSerieRed(true);
      } else {
        setSerieRed(false);
      }
      if (selectedTeachers.length === 0) {
        setSelectedTeachersRed(true);
      } else {
        setSelectedTeachersRed(false);
      }
      if (selectedResponsibles.length === 0) {
        setSeselectedResponsiblesRed(true);
      } else {
        setSeselectedResponsiblesRed(false);
      }
    } else {
      setNameRed(false);
      setBirthRed('#4F4F4F');
      setConditionRed(false);
      setGradeRed(false);
      setSerieRed(false);
      setSelectedTeachersRed(false);
      setSeselectedResponsiblesRed(false);
      toggleModalSuccess();
      onClickSubmit(createPayload());
    }
  };

  const renderButtons = () => {
    return !isEdicao ? (
      <div
        style={{ display: 'flex', justifyContent: 'center', padding: '15px' }}
      >
        <ButtonCard
          width="16.28em"
          height="3.29em"
          text=""
          icon={fontawesome.icons.faCheck}
          sizeIcon="2.25em"
          backgroundColor={colors.theme.blue}
          iconWidth="100%"
          onClick={onConfirm}
        />
      </div>
    ) : (
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <div style={{ margin: '1em' }}>
          <ButtonCard
            width="8.28em"
            height="3.29em"
            text=""
            icon={fontawesome.icons.faTrash}
            sizeIcon="2.25em"
            marginIcon="0rem"
            backgroundColor={colors.theme.cancel}
            iconWidth="100%"
            onClick={() => {
              toggleModalDelete();
            }}
          />
        </div>
        <div style={{ margin: '1em' }}>
          <ButtonCard
            width={isEdicao ? '8.28em' : '16.28em'}
            height="3.29em"
            text=""
            icon={fontawesome.icons.faCheck}
            sizeIcon="2.25em"
            backgroundColor={colors.theme.blue}
            iconWidth="100%"
            marginIcon="0rem"
            onClick={onConfirm}
          />
        </div>
      </div>
    );
  };

  return (
    <div className={className} style={{ padding: '20px' }}>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Nome completo do aluno"
          borderColor={nameRed ? colors.theme.cancel : colors.theme.text_icon}
          acceptValue
          value={name}
          onChange={event => setName(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <InputMask
          style={{
            width: '85%',
            maxWidth: '66.8rem',
            minWidth: '20.1875rem',
            height: '3.25rem',
            margin: '1.5625rem 0rem 0rem 0rem',
            padding: '17px 14px 17px 17px',
            borderRadius: '0.3125rem',
            border: '1px solid',
            borderColor: `${birthRed}`,
          }}
          placeholder="Data de nascimento"
          mask="99/99/9999"
          value={birth}
          onChange={(event: any) => {
            setBirth(event.target.value);
          }}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Síndrome/Condição"
          borderColor={
            conditionRed ? colors.theme.cancel : colors.theme.text_icon
          }
          acceptValue
          value={condition}
          onChange={event => setCondition(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Grau da Síndrome"
          borderColor={gradeRed ? colors.theme.cancel : colors.theme.text_icon}
          acceptValue
          value={grade}
          onChange={event => setGrade(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Série do Aluno"
          borderColor={serieRed ? colors.theme.cancel : colors.theme.text_icon}
          acceptValue
          value={serie}
          onChange={event => setSerie(event.target.value)}
        />
      </div>
      <div
        style={{
          paddingTop: '0.625rem',
        }}
      >
        <TextArea
          placeholder="Observações"
          acceptValue
          value={observations}
          setChange={event => setObservations(event.target.value)}
        />
      </div>
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          paddingTop: '0.625rem',
        }}
      >
        <DropDown
          selectText="Professores"
          isMulti
          onChange={value => {
            const selected = Array<number>();
            for (let i = 0; i < value.length; i++) {
              selected.push(value[i].value);
            }
            console.log(selected);
            setSelectedTeachers(selected);
          }}
          options={teachers}
          val={selectedTeachers}
        />
      </div>
      {selectedTeachersRed && (
        <span style={{ color: colors.theme.cancel }}>
          Selecione ao menos um professor.
        </span>
      )}
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          paddingTop: '0.625rem',
        }}
      >
        <DropDown
          selectText="Responsáveis"
          isMulti
          onChange={value => {
            const selected = Array<number>();
            for (let i = 0; i < value.length; i++) {
              selected.push(value[i].value);
            }
            setSelectedResponsibles(selected);
          }}
          options={responsibles}
          val={selectedResponsibles}
        />
      </div>
      {selectedResponsiblesRed && (
        <span style={{ color: colors.theme.cancel }}>
          Selecione ao menos um responsável.
        </span>
      )}

      {renderButtons()}

      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários corretamente."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Aluno cadastrado com successo."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalSuccess();
              navigate(-1);
            }}
          />
        </div>
      )}
      {modalDelete && (
        <div style={styles.modal}>
          <Modal
            text="Tem certeza que deseja excluir este aluno?"
            closeModal={toggleModalDelete}
            noButton={toggleModalDelete}
            checkButton={() => {
              toggleModalDelete();
              handleClickDelete();
              toggleModalDeleteConfirmed();
            }}
          />
        </div>
      )}
      {modalDeleteConfirmed && (
        <div style={styles.modal}>
          <Modal
            text="Aluno deletado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalDeleteConfirmed();
              navigate(-1);
            }}
          />
        </div>
      )}
    </div>
  );
}

FormComponentStudent.defaultProps = defaultProps;

export default FormComponentStudent;
