import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
// import { slide as Menu } from 'react-burger-menu';
import { useNavigate } from 'react-router-dom';
import Puzzle from '../components/Puzzle';
import { Annotation } from '../services/annotation';

import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  isPuzzle: true,
  enableHamburguer: false,
  className: 'header',
  enableBars: false,
  text: 'Área do Professor',
  disableText: true,
  buttonColor: colors.theme.iconHeader,
  disableArrow: true,
  onClickBars: () => {
    console.log('clicou');
  },
  enableLogout: false,
  hamburguerList: new Array<Annotation>(),
};

type HeaderProps = {
  isPuzzle?: boolean;
  className?: string;
  enableBars?: boolean;
  text?: string;
  disableText?: boolean;
  buttonColor?: string;
  disableArrow?: boolean;
  enableHamburguer?: boolean;
  onClickBars?: () => void;
  enableLogout?: boolean;
  hamburguerList?: Annotation[];
} & typeof defaultProps;

function Header(props: HeaderProps) {
  const navigate = useNavigate();
  const {
    isPuzzle,
    enableHamburguer,
    className,
    enableBars,
    text,
    disableText,
    buttonColor,
    disableArrow,
    onClickBars,
    enableLogout,
    hamburguerList,
  } = props;

  const logout = () => {
    sessionStorage.clear();
    navigate('/');
  };

  const stylesMenu = {
    bmBurgerButton: {
      position: 'fixed',
      width: '36px',
      height: '30px',
      right: '36px',
      top: '36px',
    },
    bmBurgerBars: {
      background: '#3E598F',
    },
    bmBurgerBarsHover: {
      background: '#a90000',
    },
    bmCrossButton: {
      height: '24px',
      width: '24px',
      left: '36px',
    },
    bmCross: {
      background: 'transparent',
      color: '#fff',
    },
    bmMenuWrap: {
      position: 'fixed',
      height: '100%',
    },
    bmMenu: {
      background: '#92C3DE',
      padding: '2.5em 1.5em 0',
      fontSize: '1.15em',
    },
    bmMorphShape: {
      fill: '#373a47',
    },
    bmItemList: {
      color: '#b8b7ad',
      padding: '0.8em',
    },
    bmItem: {
      display: 'inline-block',
    },
    bmOverlay: {
      background: 'rgba(0, 0, 0, 0.3)',
    },
  };

  const styles = {
    header: {
      width: 'auto',
      height: '6.25em',
      background: colors.theme.blue,
      display: 'flex',
      justifyContent: 'space-around',
      alignItems: 'center',
      alignContent: 'center',
      borderRadius: '0px 0px 10px 10px',
    },
    text: {
      color: colors.theme.white,
      fontStyle: 'roboto',
      fontWeight: 'bold',
      fontSize: '1.5em',
      position: 'absolute' as const,
      marginBottom: '0em',
    },
    button: {
      color: `${buttonColor}`,
      height: '1.875em',
      marginRight: 'auto',
      paddingLeft: '5%',
      width: '1.875em',
    },
    buttonLogout: {
      color: `${buttonColor}`,
      height: '1em',
      marginLeft: 'auto',
      paddingRight: '5%',
      alignItems: 'flex-start',
      justifyContent: 'flex-end',
    },
  };

  const styleCard = {
    marginBottom: '1rem',
  };

  return (
    <>
      {/* {enableHamburguer && (
        <Menu
          right
          styles={stylesMenu}
          customCrossIcon={
            <FontAwesomeIcon icon={fontawesome.icons.faArrowRight} />
          }
          itemListElement="div"
        >
          {hamburguerList.map(item => {
            return (
              <div style={styleCard}>
                <CardLista
                  titleContent={`Dia ${FormatDate(item.date)}`}
                  enableIconArrow={false}
                  enableIconPen={false}
                  enableSubtitle1
                  enableSubtitle2={false}
                  enableTag={false}
                  subtitle1Content={item.content}
                  disableTitleCenter={false}
                  textColor="#000"
                  marginCard="0rem"
                  onlyTitle
                />
              </div>
            );
          })}
        </Menu>
      )} */}

      <div className={className} style={styles.header}>
        {disableArrow && (
          <FontAwesomeIcon
            icon={fontawesome.icons.faArrowLeft}
            style={styles.button}
            onClick={() => navigate(-1)}
          />
        )}
        {isPuzzle && <Puzzle />}
        {disableText && <h1 style={styles.text}>{text}</h1>}
        {enableBars && (
          <FontAwesomeIcon
            icon={fontawesome.icons.faBars}
            style={styles.button}
            onClick={onClickBars}
          />
        )}
        {enableLogout && (
          <FontAwesomeIcon
            icon={fontawesome.icons.faSignOut}
            style={styles.buttonLogout}
            onClick={() => logout()}
          />
        )}
      </div>
    </>
  );
}

Header.defaultProps = defaultProps;

export default Header;
