import { IconDefinition } from '@fortawesome/free-regular-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React, { useState } from 'react';

import { ButtonCard } from '../components';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const defaultProps = {
  className: 'className',
  backgroundColor: colors.theme.blue,
  textColor: colors.theme.iconHeader,
  text: 'Tem certeza que deseja excluir esse usuario?',
  textSize: '1em',
  width: '17.5em',
  height: '21.75em',
  marginTop: '14.8125em',
  areYouSureModal: true,
  textMargin: '0.5em 0 1.5em 0',
  multipleButtons: false,
  justTwoButtons: false,
  hasWarningSign: true,
  multipleButtonsText1: 'Cadastrar professor',
  multipleButtonsText2: 'Cadastrar responsável',
  multipleButtonsText3: 'Cadastrar especialista',
  icon: fontawesome.icons.faRectangleXmark,
  onClickRegistration1: () => {
    console.log('button 1 click');
  },
  onClickRegistration2: () => {
    console.log('button 2 click');
  },
  onClickRegistration3: () => {
    console.log('button 3 click');
  },
  closeModal: () => {
    console.log('close');
  },
  checkButton: () => {
    console.log('check');
  },
  noButton: () => {
    console.log('x');
  },
};

type ModalProps = {
  className?: string;
  width?: string;
  height?: string;
  backgroundColor?: string;
  text?: string;
  textColor?: string;
  textSize?: string;
  textMargin?: string;
  icon?: IconDefinition;
  areYouSureModal?: boolean;
  multipleButtons?: boolean;
  justTwoButtons?: boolean;
  hasWarningSign?: boolean;
  multipleButtonsText1?: string;
  multipleButtonsText2?: string;
  multipleButtonsText3?: string;
  marginTop?: string;
  onClickRegistration1?: () => void;
  onClickRegistration2?: () => void;
  onClickRegistration3?: () => void;
  closeModal?: () => void;
  checkButton?: () => void;
  noButton?: () => void;
} & typeof defaultProps;

function Modal(props: ModalProps) {
  const {
    className,
    width,
    height,
    backgroundColor,
    text,
    textColor,
    textSize,
    textMargin,
    icon,
    areYouSureModal,
    multipleButtons,
    multipleButtonsText1,
    multipleButtonsText2,
    multipleButtonsText3,
    justTwoButtons,
    hasWarningSign,
    marginTop,
    onClickRegistration1,
    onClickRegistration2,
    onClickRegistration3,
    closeModal,
    checkButton,
    noButton,
  } = props;

  const styles = {
    container: {
      display: 'flex',
      justifyContent: 'center',
    },
    modal: {
      backgroundColor,
      color: textColor,
      fontSize: textSize,
      fontStyle: 'roboto',
      fontWeight: '500',
      width,
      height,
      borderRadius: '0.3125em',
      marginTop,
      icon,
    },
    closeX: {
      margin: '0.4rem 0rem 0rem 0.49rem',
    },
    icon: {
      // Substituir aquele buttonCard, mais para frente
      fontSize: '1.875rem',
      marginLeft: '1.75rem',
      cursor: 'pointer',
      color: textColor,
      sizeIcon: '1.875em',
      height: '1.875em',
      width: '1.875em',
    },
    text: {
      paddingLeft: '3em',
      paddingRight: '3em',
      textAlign: 'center' as const,
      margin: textMargin,
    },
    warningContainer: {
      display: 'flex',
      justifyContent: 'center',
    },
    buttonsContainer: {
      display: 'flex',
      flexDirection: 'column' as const,
      alignItems: 'center',
      justifyContent: 'center',
      flexWrap: 'wrap' as const,
    },
    buttons: {
      marginBottom: '1.625em',
      marginRight: '0rem',
    },

    warningButton: { height: '4.3125em', width: '4.3125em' },

    test: { position: 'relative' as const },
  };

  return (
    <div>
      <div style={styles.container}>
        <div className={className} style={styles.modal}>
          <div style={styles.closeX}>
            <ButtonCard
              sizeIcon="1.875em"
              height="1.875em"
              width="1.875em"
              marginIcon="0rem"
              icon={icon}
              text=""
              color={textColor}
              onClick={() => closeModal()}
            />
          </div>
          {hasWarningSign && (
            <div style={styles.warningContainer}>
              <FontAwesomeIcon
                icon={fontawesome.icons.faTriangleExclamation}
                style={styles.warningButton}
              />
            </div>
          )}

          <div style={styles.test}>
            <div style={styles.text}>{text}</div>
          </div>

          {areYouSureModal && (
            <div style={styles.buttonsContainer}>
              <div style={styles.buttons}>
                <ButtonCard
                  sizeIcon="0px"
                  text="SIM"
                  textSize="0.8125em"
                  backgroundColor={colors.theme.confirm}
                  marginIcon="0rem"
                  fontWeight="900"
                  width="12.825em"
                  height="3.625em"
                  boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                  onClick={checkButton}
                />
              </div>
              <div style={styles.buttons}>
                <ButtonCard
                  sizeIcon="0px"
                  textSize="0.8125em"
                  text="NÃO"
                  backgroundColor={colors.theme.cancel}
                  marginIcon="0rem"
                  fontWeight="900"
                  width="12.825em"
                  height="3.625em"
                  boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                  onClick={noButton}
                />
              </div>
            </div>
          )}

          {multipleButtons && (
            <div style={styles.buttonsContainer}>
              <div style={styles.buttons}>
                <ButtonCard
                  sizeIcon="0px"
                  text={multipleButtonsText1}
                  textSize="0.8125em"
                  backgroundColor={colors.theme.white}
                  textColor={colors.theme.blue}
                  marginIcon="0rem"
                  fontWeight="900"
                  width="14.825em"
                  height="3.625em"
                  boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                  onClick={onClickRegistration1}
                />
              </div>
              <div style={styles.buttons}>
                <ButtonCard
                  sizeIcon="0px"
                  textSize="0.8125em"
                  text={multipleButtonsText2}
                  backgroundColor={colors.theme.white}
                  textColor={colors.theme.blue}
                  marginIcon="0rem"
                  fontWeight="900"
                  width="14.825em"
                  height="3.625em"
                  boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                  onClick={onClickRegistration2}
                />
              </div>
              {!justTwoButtons && (
                <div style={styles.buttons}>
                  <ButtonCard
                    sizeIcon="0px"
                    textSize="0.8125em"
                    text={multipleButtonsText3}
                    backgroundColor={colors.theme.white}
                    textColor={colors.theme.blue}
                    marginIcon="0rem"
                    fontWeight="900"
                    width="14.825em"
                    height="3.625em"
                    boxShadow="0 3px 3px 0px rgba(0, 0, 0, 0.2)"
                    onClick={onClickRegistration3}
                  />
                </div>
              )}
            </div>
          )}
        </div>
      </div>
    </div>
  );
}

Modal.defaultProps = defaultProps;

export default Modal;
