import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard, TitleComponent } from '../components';
import TextArea from '../components/TextArea';
import { Header, Modal } from '../containers';
import { User } from '../model/user';
import {
  createAnnotation,
  deleteAnnotation,
  editAnnotation,
  getAnnotationById,
  CreateAnnotationPayload,
  EditAnnotationPayload,
  Annotation,
} from '../services/annotation';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const styles = {
  modal: {
    position: 'absolute' as const,
    alignself: 'center',
    justifyContent: 'center',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
};

function AdicionarAnotacao() {
  const { idAluno, id } = useParams();
  const navigate = useNavigate();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [content, setContent] = useState<string>('');
  const [modalDelete, setModalDelete] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalDeleteConfirmed, setModalDeleteConfirmed] = useState(false);
  const [date, setDate] = useState(new Date());
  const [userSessionId, setUserSessionId] = useState(-1);

  const createPayload = (): CreateAnnotationPayload => {
    // console.log(tag);
    const payloadMaterial: CreateAnnotationPayload = {
      content,
      date: dataNova,
      teacher_id: userSessionId,
      student_id: Number(idAluno),
    };
    return payloadMaterial;
  };

  const editPayload = (): EditAnnotationPayload => {
    const payloadMaterial: EditAnnotationPayload = {
      content,
      date: date.toDateString(),
    };
    return payloadMaterial;
  };

  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalDelete = () => {
    setModalDelete(!modalDelete);
  };
  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalDeleteConfirmed = () => {
    setModalDeleteConfirmed(!modalDeleteConfirmed);
  };

  const handleClickSave = (data: CreateAnnotationPayload) => {
    if (isEdicao) editAnnotation(Number(id), data);
    else createAnnotation(data);
  };
  const handleClickDelete = () => deleteAnnotation(Number(id));

  useEffect(() => {
    const userFromSession: User = JSON.parse(
      sessionStorage.getItem('user') || '{}',
    );
    const getData = async (id: number) => {
      try {
        const getAnnotationResponse: Annotation = await getAnnotationById(id);
        setContent(getAnnotationResponse.content);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getData(Number(id));
    }
    setUserSessionId(userFromSession.id);
  }, []);

  const dd = String(date.getDate()).padStart(2, '0');
  const mm = String(date.getMonth() + 1).padStart(2, '0');
  const yyyy = String(date.getFullYear());

  const data = `Dia ${dd}/${mm}/${yyyy}`;
  const dataNova = `${dd}/${mm}/${yyyy}`;

  return (
    <div
      style={{
        backgroundColor: colors.theme.background,
        minHeight: '100vh',
        paddingBottom: '2rem',
        marginTop: '6.25rem',
      }}
    >
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={{ paddingTop: '1.563rem' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Anotação' : 'Adicionar Anotação'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <div
        style={{
          paddingTop: '1.563rem',
          paddingLeft: '1.65rem',
          display: 'flex',
          justifyContent: 'beginning',
        }}
      >
        <TitleComponent text={data} textSize="1.45em" fontWeight="600" />
      </div>
      <div
        style={{
          marginTop: '0.363rem',
        }}
      >
        <TextArea
          placeholder="Digite o conteúdo da anotação"
          height="25.5625rem"
          acceptValue
          value={content}
          setChange={event => setContent(event.target.value)}
        />
      </div>
      {isEdicao ? (
        <div
          style={{
            display: 'flex',
            justifyContent: 'center',
            marginTop: '2.75rem',
          }}
        >
          <div style={{ margin: '1em' }}>
            <ButtonCard
              text=""
              backgroundColor={colors.theme.blue}
              width="8.28rem"
              height="3.29rem"
              iconWidth="100%"
              sizeIcon="2.25em"
              marginIcon="0rem"
              icon={fontawesome.icons.faCheck}
              onClick={() => {
                handleClickSave(createPayload());
                toggleModalSuccess();
              }}
            />
          </div>
          <div style={{ margin: '1em' }}>
            <ButtonCard
              text=""
              backgroundColor={colors.theme.cancel}
              width="8.28rem"
              height="3.29rem"
              iconWidth="100%"
              sizeIcon="2.25em"
              marginIcon="0rem"
              icon={fontawesome.icons.faTrash}
              onClick={toggleModalDelete}
            />
          </div>
        </div>
      ) : (
        <div
          style={{
            display: 'flex',
            justifyContent: 'center',
            marginTop: '2.75rem',
          }}
        >
          <ButtonCard
            text=""
            backgroundColor={colors.theme.blue}
            width="16.28em"
            height="3.29em"
            iconWidth="100%"
            sizeIcon="2.25em"
            marginIcon="0rem"
            icon={fontawesome.icons.faCheck}
            onClick={() => {
              if (content.length === 0) {
                toggleModalEmpty();
              } else {
                handleClickSave(createPayload());
                toggleModalSuccess();
              }
            }}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Anotação cadastrada com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
      {modalDelete && (
        <div style={styles.modal}>
          <Modal
            text="Tem certeza que deseja excluir esta anotação?"
            closeModal={toggleModalDelete}
            checkButton={() => {
              handleClickDelete();
              navigate(-1);
            }}
            noButton={toggleModalDelete}
          />
        </div>
      )}
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalDeleteConfirmed && (
        <div style={styles.modal}>
          <Modal
            text="Anotação deletada com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalDeleteConfirmed();
              navigate(-1);
            }}
          />
        </div>
      )}
    </div>
  );
}

export default AdicionarAnotacao;
