import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard, DropDown, TextField, TitleComponent } from '../components';
import TextArea from '../components/TextArea';
import { Header, Modal } from '../containers';
import { RecvMaterial } from '../model/material';
import {
  createMaterial,
  CreateMaterialPayload,
  deleteMaterial,
  editMaterial,
  EditMaterialPayload,
  getMaterialById,
} from '../services/material';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

function AdicionarMaterial() {
  let user_json: any;
  const user = sessionStorage.getItem('user');
  if (user !== null) {
    user_json = JSON.parse(user);
  }
  const user_id = user_json.id;

  const navigate = useNavigate();

  const { id } = useParams();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [materialData, setMaterialData] = useState<RecvMaterial>();
  const handleClickSave = () => {
    if (isEdicao) editMaterial(Number(id), editPayload());
    else createMaterial(createPayload());
  };

  const handleClickDelete = () => {
    deleteMaterial(Number(id));
  };

  useEffect(() => {
    const getMaterial = async (id: number) => {
      try {
        const getMaterialsResponse: RecvMaterial = await getMaterialById(id);
        setMaterialData(getMaterialsResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getMaterial(Number(id));
    }
  }, []);

  useEffect(() => {
    if (materialData !== undefined) {
      setTitle(materialData.title);
      if (materialData.link) setLink(materialData.link);
      setContent(materialData.content);
      const tagArr = Array<string>();
      for (let i = 0; i < materialData.tags.length; i++) {
        tagArr.push(materialData.tags[i]);
      }
      setTag(tagArr);
    }
  }, [materialData]);

  const styles = {
    modal: {
      position: 'absolute' as const,
      alignself: 'center',
      justifyContent: 'center',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
    },
  };

  const [title, setTitle] = useState('');
  const [link, setLink] = useState('');
  const [content, setContent] = useState('');
  const categories = [
    { value: 'AUTISMO', label: 'Autismo' },
    { value: 'RELATO', label: 'Relato' },
    { value: 'DICA', label: 'Dica' },
    { value: 'COMPORTAMENTO', label: 'Comportamento' },
    { value: 'CURIOSIDADE', label: 'Curiosidade' },
    { value: 'LEVE', label: 'Leve' },
    { value: 'MODERADO', label: 'Moderado' },
    { value: 'AVANÇADO', label: 'Avançado' },
  ];
  const [tag, setTag] = useState(Array<string>());

  const createPayload = (): CreateMaterialPayload => {
    // console.log(tag);
    const payloadMaterial: CreateMaterialPayload = {
      title,
      link: link || undefined,
      content,
      tags: tag,
      author: user_id,
    };
    return payloadMaterial;
  };

  const editPayload = (): EditMaterialPayload => {
    // console.log(tag);
    const payloadMaterial: EditMaterialPayload = {
      title,
      link: link || undefined,
      content,
      tags: tag,
    };
    return payloadMaterial;
  };

  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalDelete, setModalDelete] = useState(false);
  const [modalDeleteConfirmed, setModalDeleteConfirmed] = useState(false);

  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalDelete = () => {
    setModalDelete(!modalDelete);
  };
  const toggleModalDeleteConfirmed = () => {
    setModalDeleteConfirmed(!modalDeleteConfirmed);
  };

  return (
    <div
      style={{ backgroundColor: colors.theme.background, minHeight: '145vh' }}
    >
      <Header text="Área do Especialista" disableArrow enableLogout />
      <div style={{ margin: '2em', marginBottom: '0.1em' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Material' : 'Adicionar Material'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <div style={{ padding: '20px' }}>
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Digite o título da postagem"
            onChange={event => setTitle(event.target.value)}
            acceptValue
            value={title}
          />
        </div>
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Link material extra (opcional)"
            onChange={event => setLink(event.target.value)}
            acceptValue
            value={link}
          />
        </div>
        <div
          style={{
            marginTop: '1.563rem',
          }}
        >
          <TextArea
            placeholder="Digite o conteúdo da postagem"
            height={isEdicao ? '15rem' : '18rem'}
            acceptValue
            value={content}
            setChange={event => setContent(event.target.value)}
          />
        </div>
        <div
          style={{
            display: 'flex',
            justifyContent: 'center',
            margin: '20px',
          }}
        >
          <DropDown
            selectText="Adicionar tags"
            options={categories}
            val={tag}
            onChange={value => {
              const selected = Array<string>();
              for (let i = 0; i < value.length; i++) {
                selected.push(value[i].value);
              }
              setTag(selected);
            }}
          />
        </div>
        <div
          style={{ display: 'flex', justifyContent: 'center', padding: '15px' }}
        >
          {isEdicao && (
            <div style={{ margin: '1em' }}>
              <ButtonCard
                width="8.28em"
                height="3.29em"
                text=""
                icon={fontawesome.icons.faTrash}
                sizeIcon="2.25em"
                marginIcon="0em"
                backgroundColor={colors.theme.cancel}
                iconWidth="100%"
                onClick={() => {
                  toggleModalDelete();
                }}
              />
            </div>
          )}
          <div style={{ margin: '1em' }}>
            <ButtonCard
              width={isEdicao ? '8.28em' : '16.28em'}
              height="3.29em"
              text=""
              icon={fontawesome.icons.faCheck}
              sizeIcon="2.25em"
              marginIcon="0em"
              backgroundColor={colors.theme.blue}
              iconWidth="100%"
              onClick={() => {
                if (title.length === 0 || content.length === 0) {
                  toggleModalEmpty();
                } else {
                  handleClickSave();
                  toggleModalSuccess();
                }
              }}
            />
          </div>
        </div>
      </div>
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Material cadastrado com successo."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalSuccess();
              navigate(-1);
            }}
          />
        </div>
      )}
      {modalDelete && (
        <div style={styles.modal}>
          <Modal
            text="Tem certeza que deseja excluir este material?"
            closeModal={toggleModalDelete}
            noButton={toggleModalDelete}
            checkButton={() => {
              toggleModalDelete();
              handleClickDelete();
              toggleModalDeleteConfirmed();
            }}
          />
        </div>
      )}
      {modalDeleteConfirmed && (
        <div style={styles.modal}>
          <Modal
            text="Material deletado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => {
              toggleModalDeleteConfirmed();
              navigate(-1);
            }}
          />
        </div>
      )}
    </div>
  );
}

export default AdicionarMaterial;
