import { ChangeEvent, useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { ButtonCard, DropDown, TextField, TitleComponent } from '../components';
import TextArea from '../components/TextArea';
import { Header, Modal } from '../containers';
import { User } from '../model/user';
import { createPost, CreatePostPayload } from '../services/post';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const styles = {
  modal: {
    position: 'absolute' as const,
    alignself: 'center',
    justifyContent: 'center',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
};

function AdicionarPostagem() {
  const [title, setTitle] = useState('');
  const [visible_specialist, setVisible_Specialist] = useState<boolean>(true);
  const navigate = useNavigate();
  const [content, setContent] = useState<string>('');
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalEmpty, setModalEmpty] = useState(false);
  const [userSessionId, setUserSessionId] = useState(-1);
  const categories = [
    { value: 'AUTISMO', label: 'Autismo' },
    { value: 'RELATO', label: 'Relato' },
    { value: 'DICA', label: 'Dica' },
    { value: 'COMPORTAMENTO', label: 'Comportamento' },
    { value: 'CURIOSIDADE', label: 'Curiosidade' },
    { value: 'LEVE', label: 'Leve' },
    { value: 'MODERADO', label: 'Moderado' },
    { value: 'AVANÇADO', label: 'Avançado' },
  ];
  const [tags, setTags] = useState(Array<string>());

  const handleChange = (event: ChangeEvent<HTMLInputElement>) => {
    const result = event.target.value;
    if (result === 'true') {
      setVisible_Specialist(true);
    } else {
      setVisible_Specialist(false);
    }
  };

  const createPayload = (): CreatePostPayload => {
    const payloadMaterial: CreatePostPayload = {
      title,
      content,
      visible_specialist,
      user_id: userSessionId,
      tags,
    };
    return payloadMaterial;
  };

  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const handleClickSave = () => {
    createPost(createPayload());
  };

  useEffect(() => {
    const userFromSession: User = JSON.parse(
      sessionStorage.getItem('user') || '{}',
    );
    setUserSessionId(userFromSession.id);
  }, []);

  return (
    <div
      style={{
        backgroundColor: colors.theme.background,
        minHeight: '100vh',
        paddingBottom: '2rem',
        marginTop: '6.25rem',
      }}
    >
      <div className="fixed-top">
        <Header text="Área do Professor" disableArrow enableLogout />
      </div>
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          flexDirection: 'column',
          width: '100%',
        }}
      >
        <div style={{ paddingTop: '1.563rem' }}>
          <TitleComponent
            text="Adicionar Postagem"
            textSize="1.75em"
            fontWeight="600"
          />
        </div>
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Digite o título da postagem"
            onChange={event => setTitle(event.target.value)}
            acceptValue
            value={title}
          />
        </div>
        <div
          style={{
            display: 'flex',
            justifyContent: 'center',
            width: '100%',
            paddingTop: '1.163rem',
          }}
        >
          <DropDown
            selectText="Adicionar tags"
            options={categories}
            val={tags}
            onChange={value => {
              const selected = Array<string>();
              for (let i = 0; i < value.length; i++) {
                selected.push(value[i].value);
              }
              setTags(selected);
            }}
          />
        </div>
        <div
          style={{
            marginTop: '0.663rem',
          }}
        >
          <TextArea
            placeholder="Digite o conteúdo da postagem"
            height="15.5625rem"
            acceptValue
            value={content}
            setChange={event => setContent(event.target.value)}
          />
        </div>
        <div
          style={{ paddingLeft: '2rem', paddingTop: '1rem', fontWeight: '500' }}
        >
          <p>Visível para especialistas:</p>
          <form>
            <input
              type="radio"
              value="true"
              id="sim"
              onChange={handleChange}
              name="visivel"
              checked
            />
            Sim
            <input
              type="radio"
              value="false"
              id="nao"
              onChange={handleChange}
              name="visivel"
              style={{ marginLeft: '2rem' }}
            />
            Não
          </form>
        </div>
      </div>

      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          marginTop: '1.75rem',
        }}
      >
        <ButtonCard
          text=""
          backgroundColor={colors.theme.blue}
          width="8.75rem"
          height="3.25rem"
          iconWidth="100%"
          sizeIcon="2.25em"
          icon={fontawesome.icons.faXmark}
          onClick={() => navigate(-1)}
        />

        <ButtonCard
          text=""
          backgroundColor={colors.theme.blue}
          width="8.75rem"
          height="3.25rem"
          iconWidth="100%"
          sizeIcon="2.25em"
          margin="0rem 0rem 0rem 2.563rem"
          icon={fontawesome.icons.faCheck}
          onClick={() => {
            if (
              content.length === 0 ||
              title.length === 0 ||
              tags.length === 0
            ) {
              toggleModalEmpty();
            } else {
              handleClickSave();
              toggleModalSuccess();
            }
          }}
        />
      </div>

      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Postagem cadastrada com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
    </div>
  );
}

export default AdicionarPostagem;
