import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard, TitleComponent } from '../components';
import TextArea from '../components/TextArea';
import { Header, Modal } from '../containers';
import { User } from '../model/user';
import { Annotation, getFilteredAnnotations } from '../services/annotation';
import { createReport, ReportPayload } from '../services/report';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

const styles = {
  modal: {
    position: 'absolute' as const,
    alignself: 'center',
    justifyContent: 'center',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
};

function AdicionarRelatorio() {
  const { idAluno } = useParams();
  const navigate = useNavigate();
  const [content, setContent] = useState<string>('');
  const [modalSuccess, setModalSuccess] = useState(false);
  const [modalEmpty, setModalEmpty] = useState(false);
  const [userSessionId, setUserSessionId] = useState(-1);
  const [annotationList, setAnnotationList] = useState<Annotation[]>([]);

  useEffect(() => {
    const userFromSession: User = JSON.parse(
      sessionStorage.getItem('user') || '{}',
    );
    const getAnnotations = async () => {
      try {
        const getAnnotationResponse: Annotation[] =
          await getFilteredAnnotations(Number(idAluno), userFromSession.id, 15);
        console.log(getAnnotationResponse);
        console.log(userSessionId);
        setAnnotationList(getAnnotationResponse);
      } catch (err) {
        console.log(err);
      }
    };
    setUserSessionId(userFromSession.id);
    getAnnotations();
  }, []);

  const createPayload = (): ReportPayload => {
    const payloadMaterial: ReportPayload = {
      content,
      date_start: formatDateString(startDate),
      date_delivery: formatDateString(currentDate),
      teacher_id: userSessionId,
      student_id: Number(idAluno),
    };
    return payloadMaterial;
  };

  console.log(userSessionId);

  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };
  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };

  const handleClickCreate = (report: ReportPayload) => {
    createReport(report);
  };

  const formatDateString = (data: Date): string => {
    const dd = String(data.getDate()).padStart(2, '0');
    const mm = String(data.getMonth() + 1).padStart(2, '0');
    const yyyy = String(data.getFullYear());
    return `${dd}/${mm}/${yyyy}`;
  };

  const currentDate = new Date();
  const startDate = new Date();
  startDate.setDate(startDate.getDate() - 15);

  return (
    <div
      style={{
        backgroundColor: colors.theme.background,
        minHeight: '100vh',
        paddingBottom: '2rem',
        marginTop: '6.25rem',
      }}
    >
      <div className="fixed-top">
        <Header
          text="Área do Aluno"
          hamburguerList={annotationList}
          disableArrow
          enableHamburguer
        />
      </div>

      <div style={{ paddingTop: '1.563rem' }}>
        <TitleComponent
          text="Adicionar relatório"
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <div
        style={{
          marginTop: '0.25rem',
          display: 'flex',
          justifyContent: 'center',
        }}
      >
        <TitleComponent
          text={`${formatDateString(startDate)} - ${formatDateString(
            currentDate,
          )}`}
          textSize="1.45em"
          fontWeight="600"
        />
      </div>
      <div
        style={{
          marginTop: '1.563rem',
        }}
      >
        <TextArea
          placeholder="Digite o conteúdo do relatório"
          height="25.5625rem"
          setChange={event => setContent(event.target.value)}
        />
      </div>
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          marginTop: '2.75rem',
        }}
      >
        <ButtonCard
          text=""
          backgroundColor={colors.theme.blue}
          width="16.28em"
          height="3.29em"
          iconWidth="100%"
          sizeIcon="2.25em"
          icon={fontawesome.icons.faCheck}
          onClick={() => {
            if (content.length === 0) {
              toggleModalEmpty();
            } else {
              handleClickCreate(createPayload());
              toggleModalSuccess();
            }
          }}
        />
      </div>
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Relatório cadastrado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos necessários."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
    </div>
  );
}

export default AdicionarRelatorio;
