import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { TitleComponent } from '../components';
import CardLista from '../containers/CardLista';
import Header from '../containers/Header';
import { User } from '../model/user';
import { Annotation, getFilteredAnnotations } from '../services/annotation';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';

function AnnotationList() {
  const navigate = useNavigate();
  const { idAluno } = useParams();
  const [annotations, setAnnotations] = useState<Annotation[]>([]);
  useEffect(() => {
    const getAnnotations = async () => {
      try {
        const userFromSession: User = JSON.parse(
          sessionStorage.getItem('user') || '{}',
        );
        const getAnnotationResponse: Annotation[] =
          await getFilteredAnnotations(Number(idAluno), userFromSession.id);

        setAnnotations(getAnnotationResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getAnnotations();
  }, []);

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={styles.titleContainer}>
        <TitleComponent text="Anotações" fontWeight="600" textSize="1.75rem" />
        <FontAwesomeIcon
          icon={fontawesome.icons.faSquarePlus}
          style={styles.icon}
          onClick={() => navigate(`/area-aluno/${idAluno}/adicionar-anotacao`)}
        />
      </div>

      <div style={styles.studentListProf}>
        {annotations.length !== 0 ? (
          annotations.map(annotation => {
            const ano = annotation.date.slice(0, 4);
            const mes = annotation.date.slice(5, 7);
            const dia = annotation.date.slice(8, 10);
            const data = `Dia ${dia}/${mes}/${ano}`;
            return (
              <div key={annotation.id} style={styles.card}>
                <CardLista
                  titleContent={data}
                  subtitle1Content={annotation.content
                    .slice(0, 25)
                    .concat('...')}
                  enableIconPen={false}
                  enableIconArrow
                  enableSubtitle2={false}
                  enableTag={false}
                  marginCard="0rem"
                  onClickPen={() => navigate(`/editar-aluno/${annotation.id}`)}
                  onClickArrow={() =>
                    navigate(
                      `/area-aluno/${idAluno}/lista-anotacoes/${annotation.id}`,
                    )
                  }
                />
              </div>
            );
          })
        ) : (
          <div style={styles.card}>
            <CardLista
              titleContent="Nenhuma anotação foi encontrada"
              enableIconArrow={false}
              enableIconPen={false}
              enableSubtitle1={false}
              enableSubtitle2={false}
              enableTag={false}
              disableTitleCenter={false}
              textColor={colors.theme.cancel}
              marginCard="0rem"
              onlyTitle
            />
          </div>
        )}
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  studentListProf: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
    justifyContent: 'center',
    paddingTop: '.5rem',
    paddingBottom: '1.375rem',
  },
  studentListCoord: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  searchBar: {
    display: 'flex',
    justifyContent: 'center',
  },
  icon: {
    fontSize: '2rem',
    marginLeft: '1.75rem',
    cursor: 'pointer',
    paddingTop: '0.3rem',
  },
};

export default AnnotationList;
