import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { ButtonCard } from '../components';
import TitleComponent from '../components/TitleComponent';
import { CardLista, Header, Modal } from '../containers';
import { Student, StudentData } from '../model/student';
import { getStudentById } from '../services/student';
import { getAllData } from '../services/studentData';
import colors from '../utils/colors';

import fontawesome from '../utils/fontawesome';
import { getAge } from '../utils/formatDate';

function AreaAluno() {
  const { id } = useParams();
  const navigate = useNavigate();
  const [studentData, setStudentData] = useState<Student>();
  const [data, setData] = useState<StudentData[]>();
  const [modalChooseReport, setModalChooseRecord] = useState(false);

  const [width, setWidth] = useState<number>(window.innerWidth);
  let titleSize = 21;
  let subtitleSize = 25;

  if (width >= 475) {
    titleSize = 30;
    subtitleSize = 35;
  } else {
    titleSize = 21;
    subtitleSize = 25;
  }

  useEffect(() => {
    window.addEventListener('resize', () => setWidth(window.innerWidth));
    // setWidth(window.innerWidth); Esse nao funciona para atulizar o width
  }, [window.innerWidth]);

  useEffect(() => {
    const getStudent = async (id: number) => {
      try {
        const getStudentsResponse: Student = await getStudentById(id);
        setStudentData(getStudentsResponse);
      } catch (err) {
        console.log(err);
      }
    };
    const getAllStudentData = async (studentId: number) => {
      try {
        const getDataResponse: StudentData[] = await getAllData(studentId);
        setData(getDataResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      getStudent(Number(id));
      getAllStudentData(Number(id));
    }
  }, []);

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={styles.titleContainer}>
        <TitleComponent
          text={`${studentData?.name}`}
          textAlign="left"
          fontWeight="600"
          textSize="1.75rem"
          subtitle={getAge(studentData?.birth_date as string)}
          colorSubtitle={colors.theme.black}
        />
      </div>

      <div style={styles.buttonsContainer}>
        <div>
          <ButtonCard
            iconWidth="100%"
            text="Relatorio"
            icon={fontawesome.icons.faFilePen}
            width="8.75rem"
            height="8.75rem"
            sizeIcon="4em"
            display="block"
            onClick={() => setModalChooseRecord(!modalChooseReport)}
          />
        </div>
        <div>
          <ButtonCard
            iconWidth="100%"
            text="Anotações"
            icon={fontawesome.icons.faNoteSticky}
            width="8.75rem"
            height="8.75rem"
            sizeIcon="4em"
            display="block"
            onClick={() =>
              navigate(`/area-aluno/${studentData?.id}/lista-anotacoes`)
            }
          />
        </div>
      </div>

      <div>
        <div style={{ marginTop: '0.8rem', paddingLeft: '1.5rem' }}>
          <TitleComponent
            text="Dados do aluno"
            textAlign="left"
            textSize="1.7rem"
            fontWeight="600"
          />
        </div>
        <div
          style={{
            margin: '0.8rem 1.5rem 1.7rem 1.5rem',
          }}
        >
          <ButtonCard
            icon={fontawesome.icons.faSquarePlus}
            text="Adicionar Característica"
            width="100%"
            sizeIcon="3em"
            onClick={() =>
              navigate(`/area-aluno/${studentData?.id}/cadastrar-dado`)
            }
          />
        </div>
        <div style={styles.dataList}>
          {data?.map(data => (
            <div key={data.id} style={styles.card}>
              <CardLista
                marginCard="0rem"
                enableCardClick
                enableIconArrow={false}
                enableTag={false}
                enableSubtitle2={false}
                titleContent={
                  // eslint-disable-next-line no-nested-ternary
                  data.subject.length > titleSize
                    ? data.subject.slice(0, titleSize).endsWith(' ')
                      ? `${data.subject.slice(0, titleSize - 1)}...`
                      : `${data.subject.slice(0, titleSize)}...`
                    : data.subject
                }
                subtitle1Content={
                  // eslint-disable-next-line no-nested-ternary
                  data.content.length > subtitleSize
                    ? data.content.slice(0, subtitleSize).endsWith(' ')
                      ? `${data.content.slice(0, subtitleSize - 1)}...`
                      : `${data.content.slice(0, subtitleSize)}...`
                    : data.content
                }
                onClickPen={() =>
                  navigate(
                    `/area-aluno/${studentData?.id}/editar-dado/${data.id}`,
                  )
                }
                onClickCard={() => {
                  navigate(
                    `/area-aluno/${studentData?.id}/visualizar-dado/${data.id}`,
                  );
                }}
              />
            </div>
          ))}
        </div>
      </div>
      {modalChooseReport && (
        <div style={styles.modal}>
          <Modal
            text="Selecione uma das opções abaixo:"
            hasWarningSign={false}
            areYouSureModal={false}
            multipleButtons
            justTwoButtons
            height="17rem"
            multipleButtonsText1="Adicionar relatório"
            multipleButtonsText2="Histórico de relatórios"
            backgroundColor={colors.theme.light_blue}
            closeModal={() => setModalChooseRecord(!modalChooseReport)}
            onClickRegistration1={() =>
              navigate(`/area-aluno/${studentData?.id}/adicionar-relatorio`)
            }
            onClickRegistration2={() =>
              navigate(`/area-aluno/${studentData?.id}/historico-relatorios`)
            }
          />
        </div>
      )}
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '110vh',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'flex-start',
    paddingTop: '7.688rem',
    paddingLeft: '1.5rem',
  },
  buttonsContainer: {
    display: 'flex',
    justifyContent: 'space-around' as const,
  },
  dataList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    marginLeft: '1.5rem',
    marginRight: '1.5rem',
  },
  card: {
    marginBottom: '1.438rem',
    maxWidth: '59rem',
    width: '100%',
  },
  modal: {
    position: 'absolute' as const,
    alignself: 'center',
    justifyContent: 'center',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
  },
};

export default AreaAluno;
