import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import { TitleComponent } from '../components';
import { FormComponentStudent, Header } from '../containers';
import { Student } from '../model/student';
import {
  createStudent,
  editStudent,
  CreateStudentPayload,
  getStudentById,
  StudentDto,
  deleteStudent,
} from '../services/student';
import colors from '../utils/colors';
import { FormatDate } from '../utils/formatDate';

function CadastroAluno() {
  const { id } = useParams();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [studentData, setStudentData] = useState<Student>();
  const handleClickSave = (student: CreateStudentPayload) => {
    if (isEdicao) editStudent(Number(id), student);
    else createStudent(student);
  };

  const handleClickDelete = () => {
    deleteStudent(Number(id));
  };

  useEffect(() => {
    const getStudent = async (id: number) => {
      try {
        const getStudentsResponse: StudentDto = await getStudentById(id);
        setStudentData({
          ...getStudentsResponse,
          birth_date: FormatDate(getStudentsResponse.birth_date),
        });
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getStudent(Number(id));
    }
  }, []);

  return (
    <div
      style={{ backgroundColor: colors.theme.background, minHeight: '100vh' }}
    >
      <Header text="Área do Coordenador" disableArrow enableLogout />
      <div style={{ margin: '2em', marginBottom: '0.1em' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Aluno' : 'Cadastrar Aluno'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <FormComponentStudent
        studentData={studentData}
        onClickSubmit={handleClickSave}
        isEdicao={isEdicao}
        handleClickDelete={handleClickDelete}
      />
    </div>
  );
}

export default CadastroAluno;
