import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import { TitleComponent } from '../components';
import { Header } from '../containers';
import FormComponent, { FormComponentData } from '../containers/FormComponent';
import {
  createSpecialist,
  getSpecialistById,
  SpecialistPayload,
  updateSpecialist,
} from '../services/specialist';
import colors from '../utils/colors';

function CadastroEspecialista() {
  const { id } = useParams();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [specData, setSpecData] = useState<SpecialistPayload>();

  useEffect(() => {
    const getSpec = async (id: number) => {
      try {
        const getSpecResponse: SpecialistPayload = await getSpecialistById(id);
        setSpecData(getSpecResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getSpec(Number(id));
    }
  }, []);
  const handleClick = (specialist: SpecialistPayload) => {
    if (id && isEdicao) updateSpecialist(Number(id), specialist);
    else createSpecialist(specialist);
  };
  return (
    <div
      style={{ backgroundColor: colors.theme.background, minHeight: '100vh' }}
    >
      <Header text="Área do Coordenador" disableArrow enableLogout />
      <div style={{ margin: '2em', marginBottom: '0.1em' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Especialista' : 'Cadastrar Especialista'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <FormComponent
        specialist
        specData={specData}
        onClickSubmitSpec={handleClick}
        isEdicao={isEdicao}
      />
    </div>
  );
}

export default CadastroEspecialista;
