import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import TitleComponent from '../components/TitleComponent';
import { Header } from '../containers';
import FormComponent, { FormComponentData } from '../containers/FormComponent';
import { Teacher } from '../model/teacher';
import { UserType } from '../model/user';
import {
  createTeacher,
  TeacherPayload,
  getTeacherById,
  updateTeacher,
} from '../services/teacher';
import colors from '../utils/colors';

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '100vh',
  },
  buttonsContainer: {
    flex: 1,
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    alignContent: 'center',
    margin: '2em',
    marginBottom: '0.1em',
  },
  buttonTitle: {
    mmargin: '2em',
    marginBottom: '0.1em',
  },
  wrap: {
    alignItems: 'center',
    textAlign: 'center' as const,
    display: 'flex',
  },
};

function CadastroProfessor() {
  const { id } = useParams();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [teacherData, setTeacherData] = useState<TeacherPayload>();

  useEffect(() => {
    const getTeacher = async (id: number) => {
      try {
        const getTeacherResponse: TeacherPayload = await getTeacherById(id);
        console.log(await getTeacherById(id));
        setTeacherData(getTeacherResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getTeacher(Number(id));
    }
  }, []);
  const handleClick = (teacher: TeacherPayload) => {
    if (id && isEdicao) updateTeacher(Number(id), teacher);
    else createTeacher(teacher);
  };

  return (
    <div style={styles.background}>
      <Header text="Área do Coordenador" disableArrow enableLogout />
      <div style={{ margin: '2em', marginBottom: '0.1em' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Professor' : 'Cadastrar Professor'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <FormComponent
        professor
        teacherData={teacherData}
        onClickSubmitTeacher={handleClick}
        isEdicao={isEdicao}
      />
    </div>
  );
}

export default CadastroProfessor;
