import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import { TitleComponent } from '../components';
import { Header } from '../containers';
import FormComponent from '../containers/FormComponent';
import {
  createResponsible,
  getResponsibleById,
  ResponsiblePayload,
  updateResponsible,
} from '../services/responsible';
import colors from '../utils/colors';

function CadastroResponsavel() {
  const { id } = useParams();
  const [isEdicao, setIsEdicao] = useState<boolean>(false);
  const [respData, setRespData] = useState<ResponsiblePayload>();

  useEffect(() => {
    const getResponsible = async (id: number) => {
      try {
        const getResponsibleResponse: ResponsiblePayload =
          await getResponsibleById(id);
        setRespData(getResponsibleResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      setIsEdicao(true);
      getResponsible(Number(id));
    }
  }, []);
  const handleClick = (responsible: ResponsiblePayload) => {
    if (id && isEdicao) updateResponsible(Number(id), responsible);
    else createResponsible(responsible);
  };
  return (
    <div
      style={{ backgroundColor: colors.theme.background, minHeight: '100vh' }}
    >
      <Header text="Área do Coordenador" disableArrow enableLogout />
      <div style={{ margin: '2em', marginBottom: '0.1em' }}>
        <TitleComponent
          text={isEdicao ? 'Editar Responsável' : 'Cadastrar Responsável'}
          textSize="1.75em"
          fontWeight="600"
        />
      </div>
      <FormComponent
        responsible
        responsibleData={respData}
        onClickSubmitResp={handleClick}
        isEdicao={isEdicao}
      />
    </div>
  );
}

export default CadastroResponsavel;
