import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { ButtonCard, DropDown, TextField, TitleComponent } from '../components';
import { CardLista, Header } from '../containers';
import { Category } from '../model/category';
import { User } from '../model/user';
import { getAllCategory } from '../services/category';
import {
  getAllMaterials,
  getAllMaterialsFromSpecialist,
  RecvMaterial,
  searchMaterials,
} from '../services/material';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import { FormatDate } from '../utils/formatDate';

const defaultProps = {
  className: 'listaMaterialScreen',
  user: '',
  isMyMaterials: false,
};

type ListaMateriaisProps = {
  className?: string;
  user?: string;
  isMyMaterials?: boolean;
} & typeof defaultProps;

function ListaMaterialScreen(props: ListaMateriaisProps) {
  const navigate = useNavigate();
  const { className, user, isMyMaterials } = props;
  const [tags, setTags] = useState<Category[]>([]);
  const [titleSearch, setTitleSearch] = useState<string>('');
  const [tagsSearch, setTagsSearch] = useState(Array<string>());
  const [materials, setMaterials] = useState<RecvMaterial[]>([]);
  const [filteredMaterials, setFilteredMaterials] = useState(
    Array<RecvMaterial>(),
  );
  const userFromSession: User = JSON.parse(
    sessionStorage.getItem('user') || '{}',
  );

  useEffect(() => {
    const getCategories = async () => {
      try {
        const getCategoriesResponse: Category[] = await getAllCategory();
        setTags(getCategoriesResponse);
      } catch (err) {
        console.log(err);
      }
    };
    const getMaterials = async () => {
      try {
        let getMaterialsResponse: RecvMaterial[];
        if (isMyMaterials) {
          getMaterialsResponse = await getAllMaterialsFromSpecialist(
            userFromSession.id,
          );
          setFilteredMaterials(getMaterialsResponse);
        } else {
          getMaterialsResponse = await getAllMaterials();
          setMaterials(getMaterialsResponse);
        }
      } catch (err) {
        console.log(err);
      }
    };
    getCategories();
    getMaterials();
  }, []);

  useEffect(() => {
    const getMaterials = async () => {
      try {
        if (isMyMaterials) {
          const getMaterialsResponse: RecvMaterial[] = await searchMaterials(
            tagsSearch,
            titleSearch,
            userFromSession.id,
          );
          setFilteredMaterials(getMaterialsResponse);
        } else {
          const getMaterialsResponse: RecvMaterial[] = await searchMaterials(
            tagsSearch,
            titleSearch,
          );
          setMaterials(getMaterialsResponse);
        }
      } catch (err) {
        console.log(err);
      }
    };
    getMaterials();
  }, [titleSearch, tagsSearch]);

  const styles = {
    titleContainer: {
      display: 'flex',
      justifyContent: 'center',
      paddingTop: '1.5rem',
      paddingBottom: '0rem',
    },
    wrap: {
      textAlign: 'center' as const,
      paddingBottom: '10px',
    },
    wrap2: {
      display: 'flex',
      justifyContent: 'center',
    },
    background: {
      backgroundColor: colors.theme.background,
      minHeight: '145vh',
    },
    notMaterialText: {
      textAlign: 'center' as const,
      paddingTop: '20px',
      fontStyle: 'poppins',
    },
    icon: {
      fontSize: '2rem',
      marginLeft: '1.75rem',
      cursor: 'pointer',
      paddingTop: '0.3rem',
    },
  };

  return (
    <div className={className} style={styles.background}>
      {user === 'professor' && (
        <div>
          <Header text="Área do Professor" enableLogout />
          <div style={styles.wrap}>
            <TextField
              placeholder="Buscar..."
              borderRadius="1.875rem"
              width="20.1875rem"
              disableIcon={false}
              onChange={event => setTitleSearch(event.target.value)}
            />
          </div>
          <div style={styles.wrap2}>
            <DropDown
              selectText="Buscar tags..."
              options={tags.map(tag => {
                return {
                  value: tag.name,
                  label:
                    tag.name.charAt(0) + tag.name.substring(1).toLowerCase(),
                };
              })}
              val={tagsSearch}
              onChange={value => {
                const selected = Array<string>();
                for (let i = 0; i < value.length; i++) {
                  selected.push(value[i].value);
                }
                setTagsSearch(selected);
              }}
            />
          </div>
          {materials.length !== 0 ? (
            materials.map(materials => {
              return (
                <div key={materials.id}>
                  <CardLista
                    tagContent={materials.tags}
                    titleContent={materials.title}
                    subtitle1Content={`Postado por: ${materials?.author.name}`}
                    subtitle2Content={FormatDate(materials.created_at)}
                    enableIconPen={false}
                    onClickArrow={() =>
                      navigate(
                        `/area-professor/visualizacao-materiais/${materials?.id}`,
                      )
                    }
                  />
                </div>
              );
            })
          ) : (
            <div style={styles.notMaterialText}>
              Não tem nenhum material cadastrado
            </div>
          )}
        </div>
      )}

      {user === 'especialista' && (
        <div>
          <Header text="Área do Especialista" />
          {isMyMaterials && (
            <div style={styles.titleContainer}>
              <TitleComponent
                text="Meus Materiais"
                fontWeight="600"
                textSize="1.75rem"
              />
              <FontAwesomeIcon
                icon={fontawesome.icons.faSquarePlus}
                style={styles.icon}
                onClick={() => navigate('/adicionar-material')}
              />
            </div>
          )}
          <div style={styles.wrap}>
            <TextField
              placeholder="Buscar..."
              borderRadius="1.875rem"
              width="20.1875rem"
              disableIcon={false}
              onChange={event => setTitleSearch(event.target.value)}
            />
          </div>
          <div style={styles.wrap2}>
            <DropDown
              selectText="Buscar tags..."
              options={tags.map(tag => {
                return {
                  value: tag.name,
                  label:
                    tag.name.charAt(0) + tag.name.substring(1).toLowerCase(),
                };
              })}
              val={tagsSearch}
              onChange={value => {
                const selected = Array<string>();
                for (let i = 0; i < value.length; i++) {
                  selected.push(value[i].value);
                }
                setTagsSearch(selected);
              }}
            />
          </div>

          {!isMyMaterials && materials.length
            ? materials.map(materials => {
                return (
                  <div key={materials.id}>
                    <CardLista
                      tagContent={materials.tags}
                      titleContent={materials.title}
                      subtitle1Content={`Postado por: ${materials?.author.name}`}
                      subtitle2Content={FormatDate(materials.created_at)}
                      enableIconPen={isMyMaterials}
                      onClickArrow={() =>
                        navigate(
                          `/area-especialista/visualizacao-materiais/${materials?.id}`,
                        )
                      }
                    />
                  </div>
                );
              })
            : null}
          {isMyMaterials && filteredMaterials.length
            ? filteredMaterials.map(materials => {
                return (
                  <div key={materials.id}>
                    <CardLista
                      tagContent={materials.tags}
                      titleContent={materials.title}
                      subtitle1Content={`Postado por: ${materials?.author.name}`}
                      subtitle2Content={FormatDate(materials.created_at)}
                      enableIconPen={isMyMaterials}
                      onClickArrow={() =>
                        navigate(
                          `/area-especialista/visualizacao-materiais/${materials?.id}`,
                        )
                      }
                      onClickPen={() =>
                        navigate(
                          `/area-especialista/editar-material/${materials?.id}`,
                        )
                      }
                    />
                  </div>
                );
              })
            : null}
          {((isMyMaterials && !filteredMaterials.length) ||
            (!isMyMaterials && !materials.length)) && (
            <div style={styles.notMaterialText}>
              Não tem nenhum material cadastrado
            </div>
          )}
        </div>
      )}
    </div>
  );
}

ListaMaterialScreen.defaultProps = defaultProps;
export default ListaMaterialScreen;
