import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { idText } from 'typescript';
import TitleComponent from '../components/TitleComponent';
import CardLista from '../containers/CardLista';
import Header from '../containers/Header';
import { Report } from '../model/report';
import { User } from '../model/user';
import { getAllReports, getReportByStudent } from '../services/report';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import { FormatDate } from '../utils/formatDate';

function ReportHistory() {
  const navigate = useNavigate();
  const { idAluno } = useParams();

  const [reports, setReports] = useState<Report[]>([]);
  const [userSessionId, setUserSessionId] = useState(-1);

  useEffect(() => {
    const userFromSession: User = JSON.parse(
      sessionStorage.getItem('user') || '{}',
    );
    const getDataReports = async () => {
      try {
        const getReportDataResponse: Report[] = await getReportByStudent(
          Number(idAluno),
        );
        setReports(getReportDataResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getDataReports();
    setUserSessionId(userFromSession.id);
  }, []);

  const renderReport = (report: Report): JSX.Element => {
    return (
      <div key={report.id} style={styles.card}>
        <CardLista
          titleContent={`Relatório - ${FormatDate(report.date_delivery)}`}
          subtitle1Content={`Professor: ${report.teacher.name}`}
          fontSizeTitle="1.20rem"
          fontSizeSubtitle="0.875rem"
          enableSubtitle2={false}
          enableIconArrow={false}
          enableIconPen={false}
          enableTag={false}
          enableCardClick
          enableHR
          marginCard="0rem"
          onClickCard={() => {
            if (report.teacher.id === userSessionId) {
              navigate(`/area-aluno/${idAluno}/editar-relatorios/${report.id}`);
            } else {
              navigate(
                `/area-aluno/${idAluno}/visualizar-relatorios/${report.id}`,
              );
            }
          }}
        />
      </div>
    );
  };

  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>
      <div style={styles.titleContainer}>
        <TitleComponent
          text="Histórico de Relatórios"
          fontWeight="600"
          textSize="1.75rem"
        />
      </div>

      <div style={styles.reportList}>
        {reports.length !== 0 ? (
          reports
            .sort(
              (report1, report2) =>
                Date.parse(report2.date_delivery) -
                Date.parse(report1.date_delivery),
            )
            .map(report => renderReport(report))
        ) : (
          <div style={styles.card}>
            <CardLista
              titleContent="Nenhum relatório foi cadastrado"
              enableIconArrow={false}
              enableIconPen={false}
              enableSubtitle1={false}
              enableSubtitle2={false}
              enableTag={false}
              disableTitleCenter={false}
              textColor={colors.theme.cancel}
              marginCard="0rem"
              onlyTitle
            />
          </div>
        )}
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  reportList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
};

export default ReportHistory;
