import { useEffect, useState } from 'react';
import { useNavigate, useParams } from 'react-router-dom';
import { TextField, TitleComponent } from '../components';
import Header from '../containers/Header';
import {
  Annotation,
  getAllAnnotations,
  getAnnotationById,
} from '../services/annotation';
import colors from '../utils/colors';

function AnnotationList() {
  const navigate = useNavigate();
  const { id } = useParams();
  const [annotation, setAnnotation] = useState<Annotation>();

  useEffect(() => {
    const getAnnotation = async () => {
      try {
        const getAnnotationResponse: Annotation = await getAnnotationById(
          Number(id),
        );

        setAnnotation(getAnnotationResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getAnnotation();
  }, []);

  const ano = annotation?.date.slice(0, 4);
  const mes = annotation?.date.slice(5, 7);
  const dia = annotation?.date.slice(8, 10);
  const data = `Dia ${dia}/${mes}/${ano}`;

  if (annotation !== undefined) {
    return (
      <div style={styles.background}>
        <div className="fixed-top">
          <Header text="Área do Aluno" disableArrow enableLogout />
        </div>

        <div style={styles.titleContainer}>
          <TitleComponent text={data} fontWeight="600" textSize="1.75rem" />
        </div>

        <div style={styles.studentListProf}>
          <p>{annotation?.content}</p>
        </div>
      </div>
    );
  }
  return (
    <div style={styles.background}>
      <div className="fixed-top">
        <Header text="Área do Aluno" disableArrow enableLogout />
      </div>

      <div style={styles.titleContainer}>
        <TitleComponent text=" " fontWeight="600" textSize="1.75rem" />
      </div>
    </div>
  );
}

const styles = {
  background: {
    background: colors.theme.background,
    minHeight: '100vh',
  },
  studentListProf: {
    display: 'flex',
    backgroundColor: 'white',
    boxShadow: '0.094rem 0.156rem 0.256rem rgba(0, 0, 0, 0.25)',
    borderRadius: '0.313rem',
    flexWrap: 'wrap' as const,
    wordBreak: 'break-all' as const,
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '1rem 1rem',
    justifyContent: 'center',
    paddingTop: '.5rem',
    paddingBottom: '1.375rem',
    margin: '1.5rem',
  },
  studentListCoord: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '8.5rem',
    paddingBottom: '0.375rem',
  },
  searchBar: {
    display: 'flex',
    justifyContent: 'center',
  },
  icon: {
    fontSize: '2rem',
    marginLeft: '1.75rem',
    cursor: 'pointer',
    paddingTop: '0.3rem',
  },
};

export default AnnotationList;
