/* eslint-disable jsx-a11y/iframe-has-title */
import { useEffect, useState } from 'react';
import { useParams } from 'react-router-dom';
import Tag from '../components/Tag';
import TitleComponent from '../components/TitleComponent';
import Header from '../containers/Header';
import { RecvMaterial } from '../model/material';
import { getMaterialById } from '../services/material';
import colors from '../utils/colors';
import { FormatDate } from '../utils/formatDate';

const defaultProps = {
  user: '',
};

type VisualizacaoMateriaisProps = {
  user?: string;
} & typeof defaultProps;

function VisualizacaoMateriais(props: VisualizacaoMateriaisProps) {
  const [materialData, setMaterialData] = useState<RecvMaterial>();
  const [video, setVideo] = useState({});
  const { id } = useParams();
  const { user } = props;

  useEffect(() => {
    const getMaterial = async (id: number) => {
      try {
        const getMaterialsResponse: RecvMaterial = await getMaterialById(id);
        setMaterialData(getMaterialsResponse);
      } catch (err) {
        console.log(err);
      }
    };
    if (id) {
      getMaterial(Number(id));
    }
  }, []);

  let linkId: string | undefined | any;

  let article = false;

  if (
    materialData?.link?.includes('youtube') ||
    materialData?.link?.includes('youtu.be')
  ) {
    if (materialData?.link?.includes('watch')) {
      linkId = `https://www.youtube.com/embed/${materialData?.link?.substring(
        32,
      )}`;
    } else {
      linkId = `https://www.youtube.com/embed/${materialData?.link?.substring(
        17,
      )}`;
    }
  } else if (materialData?.link !== undefined) {
    article = true;
  }

  useEffect(() => {
    setVideo({ playerObj: video });
  }, []);

  console.log(materialData?.link);

  return (
    <div style={styles.background}>
      <div>
        <Header
          text={
            user === 'professor' ? 'Área do Professor' : 'Área do Especialista'
          }
          disableArrow
          enableLogout
        />
      </div>
      <div style={styles.title}>
        <TitleComponent
          text={materialData?.title}
          textSize="1.35em"
          fontWeight="600"
          textAlign="left"
        />
        <br />
        <h6>Autor: {materialData?.author.name}</h6>
        <h6>Postado em: {FormatDate(String(materialData?.created_at))} </h6>
      </div>
      {linkId && (
        <div style={styles.youtube}>
          <iframe
            id="ytplayer"
            width="380"
            height="300"
            src={linkId}
            frameBorder="0"
            allowFullScreen
          />
        </div>
      )}
      {article && (
        <div style={styles.content}>
          <a href={materialData?.link} target="_blank" rel="noreferrer">
            Link material externo
          </a>
        </div>
      )}
      <div style={styles.content}>
        <h1 style={styles.contentFontSize}>{materialData?.content}</h1>
      </div>
      <div style={styles.content}>
        {materialData?.tags.map(t => (
          <Tag text={t} textSize="12px" />
        ))}
      </div>
    </div>
  );
}

const styles = {
  content: {
    margin: '15px 0px 0px 30px',
  },
  contentFontSize: {
    fontSize: 16,
  },
  youtube: {
    display: 'flex',
    justifyContent: 'center',
  },
  opts: {
    height: '215',
    width: '340',
    playerVars: {
      // https://developers.google.com/youtube/player_parameters
      origin: 'http://localhost:3000',
    },
  },
  background: {
    background: colors.theme.background,
    minHeight: '145vh',
  },
  title: {
    margin: 30,
  },
  titleContainer: {
    display: 'flex',
    justifyContent: 'center',
    paddingTop: '9.5rem',
    paddingBottom: '1.375rem',
  },
  searchBar: {
    display: 'flex',
    justifyContent: 'center',
  },
  icon: {
    fontSize: '2rem',
    marginLeft: '1.75rem',
    cursor: 'pointer',
    paddingTop: '0.3rem',
  },
  userList: {
    display: 'flex',
    flexDirection: 'column' as const,
    alignItems: 'center',
    padding: '2.438rem 0rem',
  },
  card: {
    marginBottom: '1.438rem',
    minWidth: '20.188rem',
    maxWidth: '59rem',
    width: '85%',
  },
};

VisualizacaoMateriais.defaultProps = defaultProps;
export default VisualizacaoMateriais;
