/* eslint-disable no-return-assign */

import api from './api';

const serviceName = '/annotations';

export interface Annotation {
  id: number;
  content: string;
  date: string;
  teacher_id: number;
  student_id: number;
}

export interface CreateAnnotationPayload {
  content: string;
  date: string;
  teacher_id: number;
  student_id: number;
}

export interface EditAnnotationPayload {
  content: string;
  date: string;
}

export async function createAnnotation(data: CreateAnnotationPayload) {
  let response = null;
  await api
    .post(`${serviceName}`, data)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function deleteAnnotation(id: number): Promise<any> {
  let response = null;
  await api
    .delete(`${serviceName}/${id}`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editAnnotation(
  id: number,
  annotation: EditAnnotationPayload,
): Promise<Annotation> {
  const response = await api
    .put(`${serviceName}/${id}`, annotation)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getAnnotationById(id: number): Promise<Annotation> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
export async function getAllAnnotations(): Promise<Annotation[]> {
  const response = await api
    .get(`${serviceName}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getFilteredAnnotations(
  studentId: number,
  teacherId: number,
  dayRange?: number,
): Promise<Annotation[]> {
  const paramObj = { studentId, teacherId } as any;
  if (dayRange) paramObj.dayRange = dayRange;
  const response = await api
    .get(`${serviceName}`, { params: paramObj })
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
