/* eslint-disable no-return-assign */
import { User } from '../model/user';
import api from './api';

const serviceName = '/materials';

export interface Material {
  title: string;
  link?: string;
  content: string;
  tags: Array<string>;
  author: number;
}

export interface RecvMaterial {
  id: number;
  title: string;
  link?: string;
  content: string;
  tags: Array<string>;
  author: User;
  user_id: number;
  created_at: string;
}

export interface CreateMaterialPayload {
  title: string;
  link?: string;
  content: string;
  tags: Array<string>;
  author: number;
}

export interface EditMaterialPayload {
  title: string;
  link?: string;
  content: string;
  tags: Array<string>;
}

export async function createMaterial(material: Material): Promise<any> {
  let response = null;
  await api
    .post(`${serviceName}`, material)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function deleteMaterial(id: number): Promise<any> {
  let response = null;
  await api
    .delete(`${serviceName}/${id}`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editMaterial(
  id: number,
  material: EditMaterialPayload,
): Promise<Material> {
  const response = await api
    .put(`${serviceName}/${id}`, material)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getMaterialById(id: number): Promise<RecvMaterial> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getAllMaterials(): Promise<RecvMaterial[]> {
  const response = await api
    .get(`${serviceName}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getAllMaterialsFromSpecialist(
  specialistId: number,
): Promise<RecvMaterial[]> {
  const response = await api
    .get(`${serviceName}`, { params: { specialistId } })
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function searchMaterials(
  tags: string[],
  title?: string,
  specialistId?: number,
): Promise<RecvMaterial[]> {
  const params: any = {};
  if (title !== '') params.title = title;
  if (tags.length > 0) params.categoryName = tags.join(',');
  if (specialistId) params.specialistId = specialistId;

  const response = await api
    .get(`${serviceName}`, { params })
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
