/* eslint-disable no-return-assign */
import { User } from '../model/user';
import api from './api';

const serviceName = '/forum/posts';

export interface Post {
  id: number;
  title: string;
  content: string;
  date: string;
  visible_specialist: boolean;
  author: User;
  tags: string[];
}

export interface CreatePostPayload {
  title: string;
  content: string;
  visible_specialist: boolean;
  user_id: number;
  tags: string[];
}

export interface EditPostPayload {
  title: string;
  content: string;
  visible_specialist: boolean;
  tags: string[];
}

export async function createPost(post: CreatePostPayload): Promise<any> {
  let response = null;
  await api
    .post(`${serviceName}`, post)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });

  return response;
}

export async function deletePost(id: number): Promise<any> {
  let response = null;
  await api
    .delete(`${serviceName}/${id}`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editPost(
  id: number,
  post: EditPostPayload,
): Promise<Post> {
  const response = await api
    .put(`${serviceName}/${id}`, post)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getPostById(id: number): Promise<Post> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getAllPosts(): Promise<Post[]> {
  const response = await api
    .get(`${serviceName}`)
    .then(response => {
      return response.data.data;
    })
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function searchMaterials(
  titleOrAuthor?: string,
  categories?: string[],
  specialistVisibility?: boolean,
): Promise<Post[]> {
  const params: any = {};
  if (titleOrAuthor !== '') params.titleOrAuthor = titleOrAuthor;
  if (categories && categories.length > 0)
    params.categoryName = categories.join(',');
  if (specialistVisibility) params.specialistVisibility = specialistVisibility;

  const response = await api
    .get(`${serviceName}`, { params })
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
