/* eslint-disable no-return-assign */
import api from './api';

// interface ReportPayload
export interface ReportPayload {
  content: string;
  date_start: string;
  date_delivery: string;
  teacher_id: number;
  student_id: number;
}

export interface ReportUpdatePayload {
  content: string;
  date_start: string;
  date_delivery: string;
}

const serviceName = '/reports';

// criar um relatorio novo
export async function createReport(report: ReportPayload) {
  let response = null;
  await api
    .post(`${serviceName}`, report)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

// atualizar um relatorio
export async function updateReport(
  id: number,
  report: ReportUpdatePayload,
): Promise<any> {
  let response = null;
  await api
    .put(`${serviceName}/${id}`, report)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

// retorna todos os relatorios
export async function getAllReports(): Promise<any> {
  let response = null;
  await api
    .get(`${serviceName}`)
    .then(data => (response = data.data.data))
    .catch(error => {
      throw error;
    });
  return response;
}

// retornar um relatorio do código passado por id
export async function getReportById(id: number): Promise<any> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      throw error;
    });
  return response;
}

// retornar todos os relatorios do aluno passado por parametro
export async function getReportByStudent(idStudent: number): Promise<any> {
  const response = await api
    .get(`${serviceName}/student/${idStudent}`)
    .then(response => response.data.data)
    .catch(error => {
      throw error;
    });
  return response;
}

export async function send(idRelatorio: number) {
  let response = null;
  await api
    .post(`${serviceName}/${idRelatorio}/send`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}
