/* eslint-disable no-return-assign */
import { Student } from '../model/student';
import api from './api';

const serviceName = '/students';

export interface StudentDto {
  id: number;
  created_at: string;
  name: string;
  birth_date: string;
  condition: string;
  condition_level: string;
  serie: string;
  observations?: string;
  teachers: number[];
  responsibles: number[];
}

export interface CreateStudentPayload {
  name: string;
  birth_date: string;
  condition: string;
  condition_level: string;
  serie: string;
  observations?: string;
  teachers: number[];
  responsibles: number[];
}

export async function createStudent(student: CreateStudentPayload) {
  let response = null;
  await api
    .post(`${serviceName}`, student)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function getAllStudents(): Promise<StudentDto[]> {
  const response = await api.get(`${serviceName}`);
  return response.data.data;
}

export async function getAllStudentsByTeacher(
  id: number,
): Promise<StudentDto[]> {
  const response = await api
    .get(`${serviceName}`, { params: { teacherId: id } })
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function getStudentById(id: number): Promise<StudentDto> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function deleteStudent(id: number): Promise<any> {
  const response = await api
    .delete(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editStudent(
  id: number,
  student: CreateStudentPayload,
): Promise<StudentDto> {
  const response = await api
    .put(`${serviceName}/${id}`, student)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
