/* eslint-disable no-return-assign */
import api from './api';

export interface StudentDataDto {
  id: number;
  subject: string;
  content: string;
  student_id: number;
}

export interface CreateStudentDataPayload {
  subject: string;
  content: string;
}

export async function createStudentData(
  studentId: number,
  data: CreateStudentDataPayload,
) {
  let response = null;
  await api
    .post(`/students/${studentId}/data`, data)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function getAllData(studentId: number): Promise<StudentDataDto[]> {
  const response = await api.get(`/students/${studentId}/data`);
  return response.data.data;
}

export async function getStudentDataById(
  studentId: number,
  id: number,
): Promise<StudentDataDto> {
  const response = await api
    .get(`/students/${studentId}/data/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}

export async function deleteStudentData(
  studentId: number,
  id: number,
): Promise<any> {
  let response = null;
  await api
    .delete(`/students/${studentId}/data/${id}`)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function editStudentData(
  studentId: number,
  data: CreateStudentDataPayload,
  id: number,
): Promise<StudentDataDto> {
  const response = await api
    .put(`/students/${studentId}/data/${id}`, data)
    .then(response => response.data.data)
    .catch(error => {
      console.log(error);
    });
  return response;
}
