/* eslint-disable no-return-assign */
import { Teacher } from '../model/teacher';
import { UserType } from '../model/user';
import api from './api';

// interface UpdateTeacherPayload
export interface TeacherPayload {
  name: string;
  phone_number: string;
  email: string;
  document: string;
  subject?: string;
  password: string;
}

const serviceName = '/users/teachers';

export async function createTeacher(teacher: TeacherPayload) {
  let response = null;
  await api
    .post(`${serviceName}`, teacher)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function updateTeacher(
  id: number,
  teacher: TeacherPayload,
): Promise<any> {
  let response = null;
  await api
    .put(`${serviceName}/${id}`, teacher)
    .then(data => (response = data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function getAllTeachers(): Promise<any> {
  let response = null;
  await api
    .get(`${serviceName}`)
    .then(data => (response = data.data.data))
    .catch(error => {
      throw error;
    });
  return response;
}

export async function getTeacherById(id: number): Promise<any> {
  const response = await api
    .get(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      throw error;
    });
  return response;
}

export async function deleteTeacher(id: number): Promise<any> {
  const response = await api
    .delete(`${serviceName}/${id}`)
    .then(response => response.data.data)
    .catch(error => {
      throw error;
    });
  return response;
}
